=======
Credits
=======

Maintainer
----------

* Stefan Paul <stefan.paul@triumf.ca>

Contributors
------------

Suggestions, patches or bug reports have been provided by Coulter Walls,
William Porter, Pascal Reiter, Tobias Murboeck and Zack Hockenbery.

Want to add to the project? See: CONTRIBUTING.rst
